##  Business Application Fact Sheet Subtype
New subsection MCP Server with the following attributes:
Attribute | Type | Description
---|---|---
MCP Server Support | Single-select | Select whether the agent or application can be accessed via an MCP server.
MCP Server Endpoint | Text | URL to reach the MCP server.
MCP Server Classification | Single-select | Indicate whether the MCP server queries data or has writing permissions.


